@@ -15,6 +15,14 @@ class BaseModel(Model):
         if conflict_fields:
             rows = list({''.join([str(x.get(field)) for field in conflict_fields]): self.match_schema(x) for x in rows}.values())
 
+        for field in update_fields:
+            for row in rows:
+                if field in row.keys():
+                    continue
+
+                del update_fields[field]
+                break
+
         if not transaction_count:
             transaction_count = len(rows)
 
